define(
//begin v1.x content
({
	"findLabel": "查找：",
	"findTooltip": "输入要查找的文本",
	"replaceLabel": "替换为：",
	"replaceTooltip": "输入要替换成的文本",
	"findReplace": "查找和替换",
	"matchCase": "匹配大小写",
	"matchCaseTooltip": "匹配大小写",
	"backwards": "向后",
	"backwardsTooltip": "向后搜索文本",
	"replaceAllButton": "全部替换",
	"replaceAllButtonTooltip": "替换所有文本",
	"findButton": "查找",
	"findButtonTooltip": "查找文本",
	"replaceButton": "替换",
	"replaceButtonTooltip": "替换文本",
	"replaceDialogText": "已替换 ${0} 个匹配项",
	"eofDialogText": "最后一个匹配项 ${0}",
	"eofDialogTextFind": "已找到",
	"eofDialogTextReplace": "已替换"
})
//end v1.x content
);
